<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use App\CustomerProperty;
use App\CustomerStatement;
use App\UnitBlockageCriteria;
use App\Inventory;
use Carbon\Carbon;
use App\BlockUnitLog;
use DB;

class UnitBlock extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'unit:block';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Checks unit block criteria and blocks the units';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
     $unit_block_criteria=   UnitBlockageCriteria::where('status',1)->first();
     if(!empty($unit_block_criteria)){
       

       
       
        $today = \Carbon\Carbon::today();

       
        $minDueDatesSubquery = DB::table('customer_statements')
            ->select('customer_property_id', DB::raw('MIN(due_date) as min_due_date'))
            ->where('due_date', '<', $today)
            ->where('balance', '>', 0)
            ->groupBy('customer_property_id');
           
        
        $allStatements = CustomerProperty::select('customer_statements.*')
            ->joinSub($minDueDatesSubquery, 'min_due_dates', function ($join) {
                $join->on('customer_properties.id', '=', 'min_due_dates.customer_property_id');
            })
            ->join('customer_statements', function ($join) use ($today) {
                $join->on('customer_properties.id', '=', 'customer_statements.customer_property_id')
                    ->on('customer_statements.due_date', '=', 'min_due_dates.min_due_date')
                    ->whereDate('customer_statements.due_date', '<', $today)
                    ->where('customer_statements.balance', '>', 0);
            })
            ->where('customer_properties.status', CustomerProperty::approved)
            ->where('customer_properties.is_deleted', false)
            ->get();

            foreach ($allStatements  as $pro) {
              
                $dueDate = Carbon::parse($pro->due_date);
                $today = Carbon::today();
                $differenceInDays = $today->diffInDays($dueDate);
            
                $unpaid_overdue = CustomerStatement::where('customer_property_id',$pro->customer_property_id)
                ->where('due_date','<=',date('Y-m-d'))
                ->where('balance', '>', 0)
                ->value(\DB::raw("SUM(balance)"));
                $total_days=     $unit_block_criteria->total_days;
                $total_amount=      $unit_block_criteria->total_amount;
                if( $total_days >= $differenceInDays && $total_amount >=  $unpaid_overdue){
                CustomerProperty::where('id', $pro->customer_property_id)->update(['status' => Customerproperty::block, 'block_date' => date('Y-m-d')]);
                $property = CustomerProperty::find($pro->customer_property_id);
                Inventory::where('id', $property->inventory_id)->update(['status' => Inventory::block]);
                $criteria_array = array(
                    'total_days'=>  $total_days,
                    'total_amount'=>  $total_amount,

                );
                $customer_array = array(
                    'name'=>  $property->customer->name,
                    'cnic'=>   $property->customer->cnic,

                );
                 
              
              $block_unit_log= new BlockUnitLog;
              $block_unit_log->unit_detail = $this->getUnitDetail($pro->customer_property_id);
              $block_unit_log->customer_detail =    serialize($customer_array);
              $block_unit_log->block_date = date('Y-m-d');
              $block_unit_log->blockcriteria_id = $unit_block_criteria->id;
              $block_unit_log->criteria_detail =    serialize($criteria_array);
              $block_unit_log->save();
            }
               
          
              
            }
     }

    }
    public function getUnitDetail($id)
    {
        $owner=   CustomerProperty::where('id',$id)->first();
        $floor_street = '';
        if ($owner->inventory->floor) {
            $floor_street = $owner->inventory->floor->name;
        }
        $block = $owner->inventory->floor->unitBlock ? $owner->inventory->floor->unitBlock->name : '';
        $category = '';
        foreach ($owner->inventory->categories as $c) {
            $category =  $category . ' ' . $c->category->name . '' . $c->category->percent;
        }
        $size = $owner->inventory->size ? $owner->inventory->size->name : '';
        $total_price =  $owner->inventory->total_price;
        $net_pay = $owner->net_pay;
        $unit_plot_no = $owner->inventory ? $owner->inventory->unit_number : '';
        $unit_type = $owner->inventory->type->name;
        $area =    $owner->inventory->area;
        $discount = number_format($owner->discount);
        $category_cost = number_format($owner->inventory->extra_amount);
        $booking_type = '';
        if ($owner->booking_type == \App\CustomerProperty::normal) {
            $booking_type = 'Installment';
        } elseif ($owner->booking_type == \App\CustomerProperty::full_payment) {
            $booking_type = 'Full Payment';
        }
        $booking_date = date('d-m-Y', strtotime($owner->original_boooking_date));
        $schedule_start_date = '';
        if ($owner->schedule_start_date) {
            $schedule_start_date = date('d-m-Y', strtotime($owner->schedule_start_date));
        }
        $unit_array = array(
            'floor_street' => $floor_street,
            'unit_plot_no' => $unit_plot_no,
            'block' => $block,
            'unit_type' => $unit_type,
            'category' => $category,
            'area' => $area,
            'size' => $size,
            'discount' => $discount,
            'total_price' => $total_price,
            'category_cost' => $category_cost,
            'net_amt' => $net_pay,
            'booking_type' => $booking_type,
            'booking_date' => $booking_date,
            'schedule_start_date' => $schedule_start_date
        );
        // $out = array_values($unit_array);
        // return json_encode($unit_array);
        return serialize($unit_array);
        // unserialize($data);
    }
}
